@@ -1,16 +1,15 @@
 /*
- 
+
   silcnotify.h
- 
+
   Author: Pekka Riikonen <priikone@silcnet.org>
- 
-  Copyright (C) 1997 - 2001 Pekka Riikonen
- 
+
+  Copyright (C) 1997 - 2006 Pekka Riikonen
+
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
- 
+  the Free Software Foundation; version 2 of the License.
+
   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -34,7 +33,7 @@
 /****s* silccore/SilcNotifyAPI/SilcNotifyPayload
  *
  * NAME
- * 
+ *
  *    typedef struct SilcNotifyPayloadStruct *SilcNotifyPayload;
  *
  * DESCRIPTION
@@ -50,7 +49,7 @@ typedef struct SilcNotifyPayloadStruct *SilcNotifyPayload;
 /****d* silccore/SilcNotifyAPI/SilcNotifyType
  *
  * NAME
- * 
+ *
  *    typedef SilcUInt16 SilcNotifyType;
  *
  * DESCRIPTION
@@ -79,6 +78,8 @@ typedef SilcUInt16 SilcNotifyType;
 #define SILC_NOTIFY_TYPE_KILLED          13 /* Killed from the network */
 #define SILC_NOTIFY_TYPE_UMODE_CHANGE    14 /* user mode was changed */
 #define SILC_NOTIFY_TYPE_BAN             15 /* ban list change */
+#define SILC_NOTIFY_TYPE_ERROR           16 /* error notify */
+#define SILC_NOTIFY_TYPE_WATCH           17 /* watch notify */
 /***/
 
 /* Prototypes */
@@ -87,7 +88,7 @@ typedef SilcUInt16 SilcNotifyType;
  *
  * SYNOPSIS
  *
- *    SilcNotifyPayload 
+ *    SilcNotifyPayload
  *    silc_notify_payload_parse(const unsigned char *payload,
  *                              SilcUInt32 payload_len);
  *
@@ -104,24 +105,25 @@ SilcNotifyPayload silc_notify_payload_parse(const unsigned char *payload,
  *
  * SYNOPSIS
  *
- *    SilcBuffer silc_notify_payload_encode(SilcNotifyType type, SilcUInt32 argc, 
+ *    SilcBuffer silc_notify_payload_encode(SilcNotifyType type,
+ *                                          SilcUInt32 argc,
  *                                          va_list ap);
  *
  * DESCRIPTION
  *
  *    Encode notify payload with variable argument list. If `argc' is > 0
  *    argument payloads will be associated to the notify payload. Variable
- *    arguments must be {usigned char *, SilcUInt32 (len)}.
+ *    arguments must be {unsigned char *, SilcUInt32 (len)}.
  *
  ***/
-SilcBuffer silc_notify_payload_encode(SilcNotifyType type, SilcUInt32 argc, 
+SilcBuffer silc_notify_payload_encode(SilcNotifyType type, SilcUInt32 argc,
 				      va_list ap);
 
 /****f* silccore/SilcNotifyAPI/silc_notify_payload_encode_args
  *
  * SYNOPSIS
  *
- *    SilcBuffer silc_notify_payload_encode_args(SilcNotifyType type, 
+ *    SilcBuffer silc_notify_payload_encode_args(SilcNotifyType type,
  *                                               SilcUInt32 argc,
  *                                               SilcBuffer args);
  *
@@ -131,7 +133,7 @@ SilcBuffer silc_notify_payload_encode(SilcNotifyType type, SilcUInt32 argc,
  *    encoded Argument Payload buffer.
  *
  ***/
-SilcBuffer silc_notify_payload_encode_args(SilcNotifyType type, 
+SilcBuffer silc_notify_payload_encode_args(SilcNotifyType type,
 					   SilcUInt32 argc,
 					   SilcBuffer args);
 
